==> qtjambi-remoteobjects-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiRemoteObjects/QRemoteObjectHost_shell.h <==
#ifndef QREMOTEOBJECTHOST_SHELL_H
#define QREMOTEOBJECTHOST_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectHost_shell : public QRemoteObjectHost, public QtJambiShellInterface
{
public:
    QRemoteObjectHost_shell(QObject* parent0 = nullptr);
    QRemoteObjectHost_shell(const QUrl& address0, QObject* parent1);
    QRemoteObjectHost_shell(const QUrl& address0, const QUrl& registryAddress1 = QUrl(), QRemoteObjectHostBase::AllowedSchemas allowedSchemas2 = QRemoteObjectHostBase::BuiltInSchemasOnly, QObject* parent3 = nullptr);
    ~QRemoteObjectHost_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QUrl hostUrl() const override;
    bool setHostUrl(const QUrl& hostAddress0, QRemoteObjectHostBase::AllowedSchemas allowedSchemas1) override;
    void setName(const QString& name0) override;
    bool setRegistryUrl(const QUrl& registryAddress0) override;
    void timerEvent(QTimerEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectHost_access : public QRemoteObjectHost
{
    jobject __qt_hostUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_setHostUrl_cref_QUrl_QRemoteObjectHostBase_AllowedSchemas(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID hostAddress0, jint allowedSchemas1);
};

#endif // QREMOTEOBJECTHOST_SHELL_H

==> qtjambi-remoteobjects-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiRemoteObjects/QRemoteObjectHost_shell.h <==
#ifndef QREMOTEOBJECTHOST_SHELL_H
#define QREMOTEOBJECTHOST_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtRemoteObjects/qremoteobjectabstractitemmodelreplica.h>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtRemoteObjects/qremoteobjectregistry.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtJambi/RegistryAPI>


class QRemoteObjectHost_shell : public QRemoteObjectHost, public QtJambiShellInterface
{
public:
    QRemoteObjectHost_shell(QObject* parent0 = nullptr);
    QRemoteObjectHost_shell(const QUrl& address0, QObject* parent1);
    QRemoteObjectHost_shell(const QUrl& address0, const QUrl& registryAddress1 = QUrl(), QRemoteObjectHostBase::AllowedSchemas allowedSchemas2 = QRemoteObjectHostBase::BuiltInSchemasOnly, QObject* parent3 = nullptr);
    ~QRemoteObjectHost_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QUrl hostUrl() const override;
    bool setHostUrl(const QUrl& hostAddress0, QRemoteObjectHostBase::AllowedSchemas allowedSchemas1) override;
    void setName(const QString& name0) override;
    bool setRegistryUrl(const QUrl& registryAddress0) override;
    void timerEvent(QTimerEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRemoteObjectHost_access : public QRemoteObjectHost
{
    jobject __qt_hostUrl_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_setHostUrl_cref_QUrl_QRemoteObjectHostBase_AllowedSchemas(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID hostAddress0, jint allowedSchemas1);
};

#endif // QREMOTEOBJECTHOST_SHELL_H
